"""
Ciram Client
------------
A HTTPS client to get data from CIRAM services.
"""

import urllib3
import json

from datetime import date
from cirampy.content_extractor import CiramContentExtractor
from cirampy.county import County
from cirampy.weather_forecast import CountyWeatherForecast


class CiramClient:
    def get_content(self, path: str = '/'):
        """Returns CIRAM website contents."""
        url = f'https://ciram.epagri.sc.gov.br{path}'
        http = urllib3.PoolManager()
        response = http.request('GET', url)
        content = response.data
        return content

    def get_region_weather_forecast(self):
        """Returns today's region weather forecast."""
        now = date.today()
        path = f'/index.php/{now.year:04d}/{now.month:02d}/{now.day:02d}/previsao-5-dias'
        content = self.get_content(path)
        forecast = CiramContentExtractor.region_weather_forecast(content)
        return forecast

    def get_county_list(self):
        """Returns a list of counties from Santa Catarina State."""
        path = f'/api/prevmuni-server/resources/listaJson/muni'
        content = self.get_content(path)
        counties = json.loads(content, object_hook=lambda x: County(int(x['valor']), x['texto']))
        return counties

    def get_county_weather_forecast(self, county_id: int):
        """Returns today's weather forecast for a specific county ID."""
        path = f'/api/prevmuni-server/resources/listaJson/prevMuniDia?cdCidade={county_id}'
        content = self.get_content(path)
        forecasts = json.loads(content)
        forecast_today = forecasts[0]
        forecast = CountyWeatherForecast(forecast_today['data'],
                                         county_id,
                                         forecast_today['nmCondicao'],
                                         forecast_today['curTemp'],
                                         forecast_today['tempMin'],
                                         forecast_today['tempMax'],
                                         forecast_today['nmMunicipio'])
        return forecast
