from lxml import html
from datetime import date
from cirampy.utils.datetime_ptbr import parse_ptbr_date
from cirampy.weather_forecast import RegionWeatherForecast


class CiramContentExtractor:

    @staticmethod
    def region_weather_forecast(content: bytes):
        """Extracts regional weather forecast from a CIRAM's webpage articles."""
        extractor = CiramWeatherForecastContentExtractor(content)
        forecast = RegionWeatherForecast(
            extractor.date,
            extractor.title,
            extractor.description)
        return forecast


class CiramWeatherForecastContentExtractor:

    DESCRIPTION_SUBSTR_START = 'Tempo: '
    DESCRIPTION_SUBSTR_END = 'Temperatura:'

    def __init__(self, content: bytes):

        def extract_title():
            strip = article_text.strip('\r\t\n')
            nl = strip.find('\n')
            title = strip[:nl]
            return title

        def extract_description():
            match_start = article_text.find(CiramWeatherForecastContentExtractor.DESCRIPTION_SUBSTR_START)
            slice_start = match_start + len(CiramWeatherForecastContentExtractor.DESCRIPTION_SUBSTR_START)
            match_end = article_text.find(CiramWeatherForecastContentExtractor.DESCRIPTION_SUBSTR_END)
            slice_end = match_end
            description = article_text[slice_start:slice_end].strip()
            return description

        def extract_date():
            date_str = tree.xpath('/html/body/div[1]/div/main/div/div/div/article/ul/li[1]/*')[1].tail.strip()
            return parse_ptbr_date(date_str)

        tree = html.fromstring(content)
        article_text = tree.xpath(
            'string(/html/body/div[1]/div/main/div/div/div/article/div[@class=\'entry-content clr\'])')
        self.title: str = extract_title()
        self.description: str = extract_description()
        self.date: date = extract_date()
